@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: authenticate
-version: 1.3.2.11
-id: authenticate-1.3.2.11-aaa23051add4be42425b78d4cadc236c
-key: authe_FvqiGXIBUkADfOD873EmuC
+version: 1.3.3
+id: authenticate-1.3.3-737b5333b0b8f4ef94111663d9d22000
+key: authe_0MA6DvnrNIS2Mu488OU37l
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -20,29 +20,29 @@ exposed-modules:
 hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                 OpenId2.Normalization OpenId2.Types OpenId2.XRDS
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.2.11
-library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.2.11
-data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.2.11
-hs-libraries: HSauthenticate-1.3.2.11-FvqiGXIBUkADfOD873EmuC
+import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
+library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
+data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.3
+hs-libraries: HSauthenticate-1.3.3-0MA6DvnrNIS2Mu488OU37l
 depends:
-    aeson-0.10.0.0-b63a88a6e7bf231c11601ff561c0eb0d
-    attoparsec-0.13.0.1-57451b44323b331c08be1b712bdc3810
+    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
+    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-adef087994cafeb1970772b79d5f710a
+    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    case-insensitive-1.2.0.5-0be5e2a885602c48fdae255d4ef6b04b
+    case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
     conduit-1.2.6.1-99a58e37479a2070047844a872c4445f
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    http-conduit-2.1.8-b225c20ac1fcbbf432d8f808f3157496
-    http-types-0.9-26f1bedc2b9255e48a8e673fef6095b1
+    http-conduit-2.1.8-27d1393c2c1993a0373ed4eef1793cf2
+    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
     monad-control-1.0.0.4-fa18b603f1c859e06ea8fbebdf00a3e7
-    network-uri-2.6.0.3-f06058f927fb674b53980227bb9fbb26
+    network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
     resourcet-1.1.7-7e93b08fc7a9dc3281fd76904261e146
-    tagstream-conduit-0.5.5.3-c127cfc4f7ba4a5ecccb7f6061f92667
-    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
+    tagstream-conduit-0.5.5.3-a5374a0f8ba6347b0d56f4690846feac
+    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.6.0-08e36bb27daebf8e082345cc5a0772e7
-    xml-conduit-1.3.3-072627a456ca659259d8024f0aef487d
+    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
+    xml-conduit-1.3.3-015e9953b0f75ba36e24f916204128dc
 haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
 haddock-html: /usr/share/doc/haskell-authenticate/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
